Package: imaginarycss
Version: 0.1.0
Title: Tools for Studying Imaginary Cognitive Social Structure
Description: Provides functions to measure and test imaginary cognitive social structure (CSS) motifs, which are patterns of perceived relationships among individuals in a social network. Includes tools for calculating motif frequencies, comparing observed motifs to expected distributions, and visualizing motif structures. Implements methods described in Tanaka and Vega Yon (2023) <doi:10.1016/j.socnet.2023.11.005>.
URL: https://gvegayon.github.io/imaginary-structures/
BugReports: https://github.com/gvegayon/imaginary-structures/issues
Authors@R: c(person(given="Sima", family="Najafzadehkhoei", role=c("aut","cre"), email="sima.njf@utah.edu", comment=c(ORCID="0009-0002-6253-2910")), person(given="George", family="Vega Yon", role="aut", email="g.vegayon@gmail.com", comment=c(ORCID="0000-0002-3171-0844")), person(given="Kyosuke", family="Tanaka", role="aut", email="kyokke.tanaka@gmail.com", comment=c(ORCID="0000-0002-1850-6814")))
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
LinkingTo: Rcpp, barry
Imports: graphics, Rcpp, stats
Suggests: knitr, rmarkdown, tinytest, quarto
Depends: R (>= 4.0.0)
VignetteBuilder: quarto
NeedsCompilation: yes
Packaged: 2026-02-26 22:35:59 UTC; u1418987
Author: Sima Najafzadehkhoei [aut, cre] (ORCID:
    <https://orcid.org/0009-0002-6253-2910>),
  George Vega Yon [aut] (ORCID: <https://orcid.org/0000-0002-3171-0844>),
  Kyosuke Tanaka [aut] (ORCID: <https://orcid.org/0000-0002-1850-6814>)
Maintainer: Sima Najafzadehkhoei <sima.njf@utah.edu>
Repository: CRAN
Date/Publication: 2026-03-04 09:50:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 20:11:16 UTC; unix
Archs: imaginarycss.so.dSYM
