# Generated by roxygen2: do not edit by hand

S3method(new_barry_graph,list)
S3method(new_barry_graph,matrix)
S3method(plot,imaginarycss_test)
S3method(print,barry_graph)
S3method(print,imaginarycss_test)
S3method(summary,imaginary_census)
S3method(summary,imaginarycss_test)
export(barray_to_edgelist)
export(count_imaginary_census)
export(count_recip_errors)
export(netsize)
export(new_barry_graph)
export(nnets)
export(sample_css_network)
export(test_imaginary_census)
export(tie_level_accuracy)
importFrom(Rcpp,sourceCpp)
importFrom(graphics,abline)
importFrom(graphics,barplot)
importFrom(graphics,par)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
useDynLib(imaginarycss, .registration = TRUE)
